==> web-fw2_2_2.zip: web-fw2_2_2/j2src/weber/org/itscool/weber/tag/OptionTag.java <==
package org.itscool.weber.tag;

import javax.servlet.jsp.JspException;
import javax.servlet.jsp.tagext.BodyContent;

import org.itscool.commons.util.TagUtil;
import org.itscool.weber.action.Globals;

/**
 * HTML&lt;select&gt;^O&lt;option&gt;^O𐶐^OłB<BR>
 * ΉBeañvpeBlIvV̒lƈv̏ꍇ͂̃IvV
 * IꂽԂŕ\܂B<BR>
 * ΉBean݂AselectedvpeBtruȅꍇ́ÃIvV
 * IꂽԂŕ\܂B<BR>
 * <BR>
 *yz<BR>
 * name ̃tB[h̏lݒ肷ۂɎgBean̖O(K{)<BR>
 * property nameŎw肵IuWFNg̃vpeBw肵܂B(ȗ\)<BR>
 *          propertyw肳ĂȂꍇnameŎ擾CX^XtoString()Ԃ܂<BR>
 * subproperty propertyɂĎ擾IuWFNg̃ow肷ƂɎgp܂B<BR>
 * scope propertỹXR[vw肵܂irequest, session, application)<BR>
 * 
 * @author KANO
 * @since jdk1.4.1
 * @version 1.00A 2004/11/1
*/
public class OptionTag extends HtmlBodyTag {

    /** selected */
    protected boolean selected;
	
    /**
     * @return selected擾܂
     */
    public boolean getSelected() {
        return selected;
    }
    /**
     * @param selected selected ݒ肵܂B
     */
    public void setSelected(boolean selected) {
        this.selected = selected;
    }
		
    /**
     * scopew肳ĂȂꍇ́ȀŃIuWFNg܂B
     * request, session, context̏
    */
    public int doStartTag() throws JspException {
        StringBuffer inputTag = new StringBuffer("<option ");
        /*
        if( htmlname != null && htmlname.length() > 0 ){
            inputTag.append( TagUtil.createAttribute("name", htmlname) );
        }else{
            inputTag.append( TagUtil.createAttribute("name", property) );
        }
        */
        if( value != null && value.toString().length() > 0){
            //Valuew肳Ăꍇ
            //Valueo͂
            inputTag.append("value=\"").append(value).append("\" ");
        }else{
            inputTag.append( TagUtil.createAttribute( pageContext, name,
        	   property, scope, "value", value));
        }
        inputTag.append(TagUtil.createAttribute("style", style));
		inputTag.append(TagUtil.createBoolAttribute("readonly", readonly));
		inputTag.append(TagUtil.createBoolAttribute("disabled", disabled));
		inputTag.append(TagUtil.createBoolAttribute("class", csClass));
        inputTag.append(this.createJavaScriptTag());
        
        //SELECT^OɃZbgꂽBeañvpeB܂B
        String selectName = (String) pageContext.getRequest().getAttribute(
        	Globals.SELECT_TAG_NAME);
        Object selectValue = TagUtil.findProperty( pageContext, 
        	Globals.SELECT_TAG_VALUE, selectName, scope);
        	
        //Option^OɃZbgꂽvpeB܂
        Object beanValue = TagUtil.findProperty(pageContext, name, property, scope);
        
		//SELECT^OɃZbgꂽvpeBOption^OɃZbgꂽ
		//vpeBvꍇcheckedIvVt܂B
        if (TagUtil.isCheckedValue(selectValue, value) ||
        TagUtil.isCheckedValue(selectValue, beanValue.toString() )) {
            inputTag.append("selected>");
        } else if(( selectValue==null || selectValue.equals("") )
        && selected ){
            inputTag.append("selected>");
        } else {
            inputTag.append(">");
        }
        
        try {
            pageContext.getOut().print(inputTag.toString());
        } catch (Exception e) {
            throw new JspException(e.getMessage());
        }
        //return EVAL_BODY_INCLUDE;
        return EVAL_BODY_AGAIN;
    }
    
    public int doAfterBody() throws JspException{
		try {
			BodyContent body = getBodyContent();
			body.writeOut(getPreviousOut());
			body.clearBody();
		} catch (Exception e) {
			throw new JspException(e.getMessage());
		}
		return SKIP_BODY;
    }
    
    public int doEndTag()  throws JspException{
        try {
            pageContext.getOut().print("</option>");
        } catch (Exception e) {
            throw new JspException(e.getMessage());
        }
        return EVAL_PAGE;
    }


}

==> web-fw3_0_2.zip: web-fw3_0_2/j2src/weber/org/itscool/weber/tag/OptionTag.java <==
package org.itscool.weber.tag;

import javax.servlet.jsp.JspException;
import javax.servlet.jsp.tagext.BodyContent;

import org.itscool.commons.util.JspTagUtil;
import org.itscool.weber.action.Globals;

/**
 * HTML&lt;select&gt;^O&lt;option&gt;^O𐶐^OłB<BR>
 * ΉBeañvpeBlIvV̒lƈv̏ꍇ͂̃IvV
 * IꂽԂŕ\܂B<BR>
 * ΉBean݂AselectedvpeBtruȅꍇ́ÃIvV
 * IꂽԂŕ\܂B<BR>
 * <BR>
 *yz<BR>
 * name ̃tB[h̏lݒ肷ۂɎgBean̖O(K{)<BR>
 * property nameŎw肵IuWFNg̃vpeBw肵܂B(ȗ\)<BR>
 *          propertyw肳ĂȂꍇnameŎ擾CX^XtoString()Ԃ܂<BR>
 * subproperty propertyɂĎ擾IuWFNg̃ow肷ƂɎgp܂B<BR>
 * scope propertỹXR[vw肵܂irequest, session, application)<BR>
 * 
 * @author KANO
 * @since jdk1.4.1
 * @version 1.00A 2004/11/1
*/
public class OptionTag extends HtmlBodyTag {

    /** selected */
    protected boolean selected;
	
    /**
     * @return selected擾܂
     */
    public boolean getSelected() {
        return selected;
    }
    /**
     * @param selected selected ݒ肵܂B
     */
    public void setSelected(boolean selected) {
        this.selected = selected;
    }
		
    /**
     * scopew肳ĂȂꍇ́ȀŃIuWFNg܂B
     * request, session, context̏
    */
    public int doStartTag() throws JspException {
        StringBuffer inputTag = new StringBuffer("<option ");
        /*
        if( htmlname != null && htmlname.length() > 0 ){
            inputTag.append( JspTagUtil.createAttribute("name", htmlname) );
        }else{
            inputTag.append( JspTagUtil.createAttribute("name", property) );
        }
        */
        if( value != null && value.toString().length() > 0){
            //Valuew肳Ăꍇ
            //Valueo͂
            inputTag.append("value=\"").append(value).append("\" ");
        }else{
            inputTag.append( JspTagUtil.createAttribute( pageContext, name,
        	   property, scope, "value", value));
        }
        inputTag.append(JspTagUtil.createAttribute("style", style));
		inputTag.append(JspTagUtil.createBoolAttribute("readonly", readonly));
		inputTag.append(JspTagUtil.createBoolAttribute("disabled", disabled));
		inputTag.append(JspTagUtil.createBoolAttribute("class", csClass));
        inputTag.append(this.createJavaScriptTag());
        
        //SELECT^OɃZbgꂽBeañvpeB܂B
        String selectName = (String) pageContext.getRequest().getAttribute(
        	Globals.SELECT_TAG_NAME);
        Object selectValue = JspTagUtil.findProperty( pageContext, 
        	Globals.SELECT_TAG_VALUE, selectName, scope);
        	
        //Option^OɃZbgꂽvpeB܂
        Object beanValue = JspTagUtil.findProperty(pageContext, name, property, scope);
        
		//SELECT^OɃZbgꂽvpeBOption^OɃZbgꂽ
		//vpeBvꍇcheckedIvVt܂B
        if (JspTagUtil.isCheckedValue(selectValue, value) ||
        JspTagUtil.isCheckedValue(selectValue, beanValue.toString() )) {
            inputTag.append("selected>");
        } else if(( selectValue==null || selectValue.equals("") )
        && selected ){
            inputTag.append("selected>");
        } else {
            inputTag.append(">");
        }
        
        try {
            pageContext.getOut().print(inputTag.toString());
        } catch (Exception e) {
            throw new JspException(e.getMessage());
        }
        //return EVAL_BODY_INCLUDE;
        return EVAL_BODY_AGAIN;
    }
    
    public int doAfterBody() throws JspException{
		try {
			BodyContent body = getBodyContent();
			body.writeOut(getPreviousOut());
			body.clearBody();
		} catch (Exception e) {
			throw new JspException(e.getMessage());
		}
		return SKIP_BODY;
    }
    
    public int doEndTag()  throws JspException{
        try {
            pageContext.getOut().print("</option>");
        } catch (Exception e) {
            throw new JspException(e.getMessage());
        }
        return EVAL_PAGE;
    }


}
